from tkinter import *
from tkinter import ttk
from tkinter import filedialog
from tkinter import messagebox
import os
import codecs
import tkinter
import sys
import codecs
from gramcorrector import *

TITLE = "Vartani"

class RoomEditor(Text, object):

    def __init__(self, master, **options):
        Text.__init__(self, master, **options)

        self.config(
            borderwidth=0,
            font="{Courier} 16",
            #foreground="green",
            #background="black",
            #insertbackground="white", # cursor
            #selectforeground="green", # selection
            #selectbackground="#008000",
            wrap=WORD, # use word wrapping
            undo=True,
            width=64,
            )

        self.filename = None # current document

    def _getfilename(self):
        return self._filename

    def _setfilename(self, filename):
        self._filename = filename
        title = os.path.basename(filename or "(Untitled document)")
        title = title + " - " + TITLE
        self.winfo_toplevel().title(title)

    filename = property(_getfilename, _setfilename)

    def clear(self):
        self.delete(1.0, END)
        

    def edit_modified(self, value=None):
        return self.tk.call(self, "edit", "modified", value)
    modified = property(edit_modified, edit_modified)

    def load(self, filename):
        text = codecs.open(filename,'r','utf-8').read()
        self.delete(1.0, END)
        self.insert(END, text)
        self.mark_set(INSERT, 1.0)
        self.modified = False
        self.filename = filename

    def save(self, filename=None):
        if filename is None:
            filename = self.filename
        f = codecs.open(filename,"wb",'utf-8')
        s = self.get(1.0, END)
        #print(s)
        try:
            f.write(s)
            #f.write("\n")
        finally:
            f.close()
        self.modified = False
        self.filename = filename

FILETYPES = [
    ("Text files", "*.txt"), ("All files", "*")
    ]

class Cancel(Exception):
    pass

def check(*args):
    words = editor.get(1.0,END).split('\n')
    for word in words:
        res = correct_sentence(word)
        if (not(word in res)):
            result.insert(INSERT, word + ':' + str(res)+'\n')
         
    #result.insert('1.0','hello')  
    

def dispAbout():
    messagebox.showinfo("About","Vartani - A Hindi Spell Checker by\n\n    Pulkit Jain  &&  Amit Sharma\n\tIIT KANPUR")

def open_as():
    #from filedialog import askopenfilename
    f = filedialog.askopenfilename(parent=root, filetypes=FILETYPES)
    if not f:
        raise Cancel
    try:
        editor.load(f)
    except IOError:
        #from messagebox import showwarning
        messagebox.showwarning("Open", "Cannot open the file.")
        raise Cancel
    #from filedialog import asksaveasfilename
    #f = filedialog.asksaveasfilename(parent=root, defaultextension=".txt")
    #if not f:
     #   raise Cancel
        #try:
    editor.save(f)
    #except IOError:
        #from messagebox import showwarning
        #messagebox.showwarning("Save As", "Cannot save the file.")
        #raise Cancel

def save_as():
    #from filedialog import asksaveasfilename
    f = filedialog.asksaveasfilename(parent=root, defaultextension=".txt")
    if not f:
        raise Cancel
    try:
        editor.save(f)
    except IOError:
        from messagebox import showwarning
        showwarning("Save As", "Cannot save the file.")
        raise Cancel

def save():
    if editor.filename:
        try:
            editor.save(editor.filename)
        except IOError:
            from messagebox import showwarning
            showwarning("Save", "Cannot save the file.")
            raise Cancel
    else:
        save_as()

def save_if_modified():
    if not editor.modified:
        return
    if askyesnocancel(TITLE, "Document modified. Save changes?"):
        save()
def askyesnocancel(title=None, message=None, **options):
    #import messagebox
    s = messagebox.Message(
        title=title, message=message,
        icon=messagebox.QUESTION,
        type=messagebox.YESNOCANCEL,
        **options).show()
    if isinstance(s, bool):
        return s
    if s == "cancel":
        raise Cancel
    return s == "yes"
def file_new(event=None):
    try:
        save_if_modified()
        editor.clear()
        result.clear()
    except Cancel:
        pass
    return "break" # don't propagate events

def file_open(event=None):
    try:
        save_if_modified()
        open_as()
    except Cancel:
        pass
    return "break"

def file_save(event=None):
    try:
        save()
    except Cancel:
        pass
    return "break"

def file_save_as(event=None):
    try:
        save_as()
    except Cancel:
        pass
    return "break"

def file_quit(event=None):
    try:
        save_if_modified()
    except Cancel:
        return
    root.destroy()

root = Tk()
#root.config(background="black")

#root.wm_state("zoomed")
menubar = Menu(root)
filemenu = Menu(menubar,tearoff=0)
filemenu.add_command(label="New" , command=file_new)
filemenu.add_command(label="Open", command=file_open)
filemenu.add_command(label="Save", command=file_save)
filemenu.add_command(label="Save", command=file_save_as)

filemenu.add_separator()
filemenu.add_command(label="Exit", command=file_quit)
menubar.add_cascade(label="File", menu=filemenu)

helpmenu = Menu(menubar,tearoff=0)
helpmenu.add_command(label="About",command=dispAbout)
menubar.add_cascade(label="Help",menu=helpmenu)
    # display the menu
root.config(menu=menubar)

eScroll = Scrollbar(root)
eScroll.pack(side=RIGHT,fill=Y)

editor = RoomEditor(root)
editor.pack(fill=BOTH, expand=1)
editor.config(yscrollcommand=eScroll.set,height=15)
editor.focus_set()
eScroll.config(command=editor.yview)

b=ttk.Button(root, text=" Check ",command=check)#.grid(column=3, row=3, sticky=W)
b.pack()


reScroll = Scrollbar(root)
reScroll.pack(side=RIGHT,fill=Y)
result = RoomEditor(root)
result.config(height=7,bd=0,yscrollcommand=reScroll.set)
result.pack(fill=BOTH,expand=1)
reScroll.config(command=result.yview)

try:
    editor.load(sys.argv[1])
except (IndexError, IOError):
    pass

root.bind("<Control-n>", file_new)
root.bind("<Control-o>", file_open)
root.bind("<Control-s>", file_save)
root.bind("<Control-Shift-S>", file_save_as)
root.bind("<Control-q>", file_quit)
#root.bind("<space>",calculate)
root.protocol("WM_DELETE_WINDOW", file_quit) # window close button

mainloop()

